@@ -34,6 +34,9 @@ pub mod BTW {
 pub mod title;
 pub mod how_to_install_archlinux;
 
+pub mod Español {}
+pub mod 日本語 {}
+
 pub use BTW::I::USE::ARCH::*;
 
 pub trait Empty {}
@@ -55,3 +58,5 @@ pub trait Clash {}
 pub trait MacOS {}
 
 pub trait Rust {}
+
+pub trait 中文 {}
